@@ -21,7 +21,7 @@ import (
 )
 
 const (
-	version = "0.3.10"
+	version = "0.3.11"
 )
 
 // Created with https://github.com/miku/zek
@@ -37,12 +37,9 @@ type StreamError struct {
 	ID      string   `xml:"id,attr"`
 	To      string   `xml:"to,attr"`
 	Error   struct {
-		Chardata        string `xml:",chardata"`
-		PolicyViolation struct {
-			Text  string `xml:",chardata"`
-			Xmlns string `xml:"xmlns,attr"`
-		} `xml:"policy-violation"`
-		Text struct {
+		Chardata string   `xml:",chardata"`
+		Any      xml.Name `xml:",any"`
+		Text     struct {
 			Text  string `xml:",chardata"`
 			Xmlns string `xml:"xmlns,attr"`
 		} `xml:"text"`
@@ -350,11 +347,9 @@ func startTLS(recordType string, c net.Conn, tlsConfig *tls.Config, timeout time
 			default:
 				fmt.Println("StartTLS:", statusNOK)
 				if err.Error() == "EOF" {
-					// TODO: Properly check for all possible server errors
-					// instead of only checking for "policy-violation".
 					err = xml.Unmarshal(buf, &serverStreamError)
 					if err == nil {
-						fmt.Println("Server sent policy-violation:",
+						fmt.Printf("StreamError: %s: %s\n", serverStreamError.Error.Any.Local,
 							serverStreamError.Error.Text.Text)
 					} else {
 						fmt.Println("Server closed connection.")
@@ -397,7 +392,7 @@ func startTLS(recordType string, c net.Conn, tlsConfig *tls.Config, timeout time
 			if err.Error() == "EOF" {
 				err = xml.Unmarshal(buf, &serverStreamError)
 				if err == nil {
-					fmt.Println("Server sent policy-violation:",
+					fmt.Printf("StreamError: %s: %s\n", serverStreamError.Error.Any.Local,
 						serverStreamError.Error.Text.Text)
 				} else {
 					fmt.Println("Server closed connection.")
